California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 060- ADULT FILMS. CONDOMS. HEALTH REQUIREMENTS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1356566 | YES ON PROP 60, FOR ADULT INDUSTRY RESPONSIBILITY (FAIR) COMMITTEE, WITH MAJOR FUNDING BY AIDS HEALTHCARE FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1385139 | NO ON PROPOSITION 60, CALIFORNIANS AGAINST WORKER HARASSMENT, SPONSORED BY THE FREE SPEECH COALITION | OPPOSE